@@ -1,11 +1,11 @@
 package HTTP::Exception::1XX;
+{
+  $HTTP::Exception::1XX::VERSION = '0.04003';
+}
 
 use strict;
 use base 'HTTP::Exception::Base';
 
-our $VERSION = '0.04001';
-$VERSION = eval $VERSION; # numify for warning-free dev releases
-
 sub is_info         () { 1  }
 sub is_success      () { '' }
 sub is_redirect     () { '' }
@@ -22,7 +22,7 @@ HTTP::Exception::1XX - Base Class for 1XX (info) Exceptions
 
 =head1 VERSION
 
-0.04001
+version 0.04003
 
 =head1 SYNOPSIS
 
@@ -90,4 +90,4 @@ by the Free Software Foundation; or the Artistic License.
 See http://dev.perl.org/licenses/ for more information.
 
 
-=cut
\ No newline at end of file
+=cut
