@@ -1,11 +1,11 @@
 package HTTP::Exception::Base;
+{
+  $HTTP::Exception::Base::VERSION = '0.04003';
+}
 
 use strict;
 use base 'Exception::Class::Base';
 
-our $VERSION = '0.04';
-$VERSION = eval $VERSION; # numify for warning-free dev releases
-
 ################################################################################
 # roll our own new, because of message
 # error, message and status_message are synonyms
@@ -46,7 +46,7 @@ HTTP::Exception::Base - Base Class for exception classes created by HTTP::Except
 
 =head1 VERSION
 
-0.04
+version 0.04003
 
 =head1 DESCRIPTION
 
@@ -109,4 +109,4 @@ by the Free Software Foundation; or the Artistic License.
 See http://dev.perl.org/licenses/ for more information.
 
 
-=cut
\ No newline at end of file
+=cut
