@@ -1,4 +1,7 @@
 package HTTP::Exception::Loader;
+{
+  $HTTP::Exception::Loader::VERSION = '0.04003';
+}
 
 use strict;
 use warnings;
@@ -11,9 +14,6 @@ use HTTP::Exception::4XX;
 use HTTP::Exception::5XX;
 use HTTP::Status;
 
-our $VERSION = '0.04001';
-$VERSION = eval $VERSION; # numify for warning-free dev releases
-
 ################################################################################
 # little bit messy, but solid
 # - first create packages for Exception::Class, so it can create them on its own
@@ -126,7 +126,7 @@ HTTP::Exception::Loader - Creates HTTP::Exception subclasses
 
 =head1 VERSION
 
-0.04001
+version 0.04003
 
 =head1 DESCRIPTION
 
@@ -190,4 +190,4 @@ by the Free Software Foundation; or the Artistic License.
 See http://dev.perl.org/licenses/ for more information.
 
 
-=cut
\ No newline at end of file
+=cut
